<?php

namespace app\models;

use Yii;
use yii\base\Model;
use app\models\Account;

/**
 * LoginForm is the model behind the login form.
 *
 * @property-read Account|null $account This property is read-only.
 *
 */
class AuthenticationForm extends Model
{
    public $mail;
    public $pswd;
    public $auto = true;

    private $account = false;


    /**
     * @return array the validation rules.
     */
    public function rules()
    {
        return [
            // accountname and password are both required
            [['mail', 'pswd'], 'required'],
            // rememberMe must be a boolean value
            ['auto', 'boolean'],
            // pswd is validated by validatePassword()
            ['pswd', 'validatePassword'],
        ];
    }

    public function attributeLabels()
    {
        return [
            'mail' => 'Почта',
            'pswd' => 'Пароль',
            'auto' => 'Запомнить'
        ];
    }

    /**
     * Validates the password.
     * This method serves as the inline validation for password.
     *
     * @param string $attribute the attribute currently being validated
     * @param array $params the additional name-value pairs given in the rule
     */
    public function validatePassword($attribute, $params)
    {
        if (!$this->hasErrors()) {
            $account = $this->getAccount();

            if (!$account || !$account->validatePassword($this->pswd)) {
                $this->addError($attribute, 'Не удалось идентифицировать');
            }
        }
    }

    /**
     * Logs in a account using the provided accountname and password.
     * @return bool whether the account is logged in successfully
     */
    public function authentication()
    {
        if ($this->validate()) {
            return Yii::$app->user->login($this->getAccount(), $this->auto ? 3600*24*30 : 0);
        }
        return false;
    }

    /**
     * Finds account by [[accountname]]
     *
     * @return Account|null
     */
    public function getAccount()
    {
        if ($this->account === false) {
            $this->account = Account::findByMail($this->mail);
        }

        return $this->account;
    }
}
